summaryrefslogtreecommitdiffstats
path: root/jjb/scripts/vpp/copy_archives.sh
diff options
context:
space:
mode:
Diffstat (limited to 'jjb/scripts/vpp/copy_archives.sh')
-rw-r--r--jjb/scripts/vpp/copy_archives.sh10
1 files changed, 5 insertions, 5 deletions
diff --git a/jjb/scripts/vpp/copy_archives.sh b/jjb/scripts/vpp/copy_archives.sh
index d69ca7e48..dafcd4aef 100644
--- a/jjb/scripts/vpp/copy_archives.sh
+++ b/jjb/scripts/vpp/copy_archives.sh
@@ -1,6 +1,6 @@
#!/usr/bin/env bash
-# Copyright (c) 2021 Cisco and/or its affiliates.
+# Copyright (c) 2023 Cisco and/or its affiliates.
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at:
@@ -30,9 +30,9 @@ set +e
# Variables read:
# - WORKSPACE - Jenkins workspace to create csit subdirectory in.
# Directories updated:
# - ${WORKSPACE}/archives/csit_current - Current patch results are copied here.
# - ${WORKSPACE}/archives/csit_parent - Parent patch results are copied here.
mkdir -p "${WORKSPACE}/archives"
-cp -Rv "${WORKSPACE}/csit_current" "${WORKSPACE}/archives"
-cp -Rv "${WORKSPACE}/csit_parent" "${WORKSPACE}/archives"
+# Using asterisk as bisect job creates variable number of directories.
+cp -Rv "${WORKSPACE}/csit_"* "${WORKSPACE}/archives"
@@ -30,9 +30,9 @@ set +e
# - WORKSPACE - Jenkins workspace to create csit subdirectory in.
# Directories updated:
-# - ${WORKSPACE}/archives/csit_current - Current patch results are copied here.
-# - ${WORKSPACE}/archives/csit_parent - Parent patch results are copied here.
+# - ${WORKSPACE}/archives/csit_* - Test results for various VPP builds are here.
+# e.g. csit_current and csit_parent for vpp per-patch perf job.
mkdir -p "${WORKSPACE}/archives"